/**
 * 演示程序当前的 “注册/登录” 等操作，是基于 “本地存储” 完成的
 * 当您要参考这个演示程序进行相关 app 的开发时，
 * 请注意将相关方法调整成 “基于服务端Service” 的实现。
 **/
(function($, owner) {
	/**
	 * 用户登录
	 **/
	owner.login = function(loginInfo, callback) {
		callback = callback || $.noop;
		loginInfo = loginInfo || {};
		loginInfo.account = loginInfo.account || '';
		loginInfo.password = loginInfo.password || '';
		if (loginInfo.account.length < 5) {
			return callback('账号最短为 5 个字符');
		}
		if (loginInfo.password.length < 6) {
			return callback('密码最短为 6 个字符');
		}
		if(phoneNumCheck(loginInfo.account)){
			return callback('请输入正确的手机号码');
		}
		var users = JSON.parse(localStorage.getItem('$users') || '[]');
		var authed = false;
		var login_error = "";
	
		jQuery.ajax(ajaxDomainAPI+'user/userlogin', {
			data: {
				phoneno: loginInfo.account,
				stupassword: loginInfo.password,
				clientVer: clientVer,
				usertype: '1'
			},
			cache: false,
			async: false,
			dataType: 'text', //服务器返回json格式数据
			type: 'post', //HTTP请求类型
			timeout: 3000, //超时时间设置为10秒；
			success: function(data) {
				data = jQuery.parseJSON(unescape(data));
				console.log("login data:" +JSON.stringify(data));
				if (data.flg == 0) {
					var userInfo = {
							login_id: data.userkey,
							studentsex: data.studentsex,
							studentimg:data.studentimg,
							focus:data.focus,
							nickname:data.nickname,
							phoneno:data.phoneno,
							location:data.location,
							studentname:data.studentname,
							honortitle:data.honortitle,
							briefintroduction:data.briefintroduction,
							hobby:data.hobby,
							gkfs:data.gkfs,
							loginUK:data.loginUK
						};
						localStorage.tdx_user_info = JSON.stringify(userInfo);
				        console.log(loginInfo.account+"登录成功.");
					
				} else {
					login_error = owner.getError(data.flg)
					elimUserInfo();
					localStorage.tdx_user_info=null;
					authed = false;
				}


			},
			error: function(xhr, type, errorThrown) {
				//异常处理；
				console.log(type);
				console.log(errorThrown);
				console.log(xhr);
				elimUserInfo();
				login_error = "系统异常，请稍候再试";
			}
		});


		if (authed) {
			return callback();
		} else {
			return callback(login_error);
		}
	};


	owner.getError = function(flg) {
		if (flg == 1) {
			return CommonConstants.LOGIN_ERROR_01;
		} else if (flg == 2) {
			return CommonConstants.LOGIN_ERROR_02;
		} else if (flg == 3) {
			return CommonConstants.LOGIN_ERROR_03;
		} else if (flg == 4) {
			return CommonConstants.LOGIN_ERROR_04;
		} else if (flg == 5) {
			return CommonConstants.LOGIN_ERROR_05;
		} else if(flg = 223){
			return CommonConstants.LOGIN_ERROR_06;
		}
	};

	/**
	 * 新用户注册
	 **/
	owner.reg = function(regInfo, callback) {
		callback = callback || $.noop;
		regInfo = regInfo || {};
		regInfo.account = regInfo.account || '';
		regInfo.password = regInfo.password || '';
		if (regInfo.account.length < 5) {
			return callback('用户名最短需要 5 个字符');
		}
		if (regInfo.password.length < 6) {
			return callback('密码最短需要 6 个字符');
		}
		if (!checkEmail(regInfo.email)) {
			return callback('邮箱地址不合法');
		}
		var users = JSON.parse(localStorage.getItem('$users') || '[]');
		users.push(regInfo);
		localStorage.setItem('$users', JSON.stringify(users));
		return callback();
	};

    owner.loginButtonShow = function(){
    	var accountBox = document.getElementById('account');
		var passwordBox = document.getElementById('password');
		
		if(isNotEmpty(accountBox.value) && isNotEmpty(passwordBox.value) && 
		    accountBox.value.length == 11 && passwordBox.value.length>=6){
			jQuery("#login").attr("disabled",false);
			jQuery("#login").attr("class","mui-btn mui-btn-block mui-btn-primary");
		} else {
			jQuery("#login").attr("disabled",true);
			jQuery("#login").attr("class","mui-btn mui-btn-block mui-btn-default");
		}
    };

	/**
	 * 获取当前状态
	 **/
	owner.getState = function() {
		var stateText = localStorage.getItem('$state') || "{}";
		return JSON.parse(stateText);
	};

	/**
	 * 设置当前状态
	 **/
	owner.setState = function(state) {
		state = state || {};
		localStorage.setItem('$state', JSON.stringify(state));
		//var settings = owner.getSettings();
		//settings.gestures = '';
		//owner.setSettings(settings);
	};

	var checkEmail = function(email) {
		email = email || '';
		return (email.length > 3 && email.indexOf('@') > -1);
	};

	/**
	 * 找回密码
	 **/
	owner.forgetPassword = function(email, callback) {
		callback = callback || $.noop;
		if (!checkEmail(email)) {
			return callback('邮箱地址不合法');
		}
		return callback(null, '新的随机密码已经发送到您的邮箱，请查收邮件。');
	};

	/**
	 * 获取应用本地配置
	 **/
	owner.setSettings = function(settings) {
		settings = settings || {};
		localStorage.setItem('$settings', JSON.stringify(settings));
	}

	/**
	 * 设置应用本地配置
	 **/
	owner.getSettings = function() {
		var settingsText = localStorage.getItem('$settings') || "{}";
		return JSON.parse(settingsText);
	}
	

}(mui, window.app = {}));